@@ -2,12 +2,9 @@ import importlib
 import os
 
 import mock
-import pytest
 
 from . import util
 
-pytestmark = pytest.mark.skipif(True, reason='examples_tests are broken.')
-
 
 path = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'examples')
 
